summaryrefslogtreecommitdiffstats
path: root/krita/core/kis_gradient.h
diff options
context:
space:
mode:
Diffstat (limited to 'krita/core/kis_gradient.h')
-rw-r--r--krita/core/kis_gradient.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/krita/core/kis_gradient.h b/krita/core/kis_gradient.h
index 3610e0e0..50bc0fd8 100644
--- a/krita/core/kis_gradient.h
+++ b/krita/core/kis_gradient.h
@@ -24,15 +24,15 @@
#ifndef KIS_GRADIENT_H
#define KIS_GRADIENT_H
-#include <qvaluevector.h>
-#include <qcolor.h>
+#include <tqvaluevector.h>
+#include <tqcolor.h>
#include <kio/job.h>
#include "kis_resource.h"
#include "kis_global.h"
-class QImage;
+class TQImage;
enum {
INTERP_LINEAR = 0,
@@ -48,17 +48,17 @@ enum {
COLOR_INTERP_HSV_CW
};
// TODO: Replace QColor with KisColor
class Color {
public:
Color() { m_alpha = 0; }
- Color(const QColor& color, double alpha) { m_color = color; m_alpha = alpha; }
+ Color(const TQColor& color, double alpha) { m_color = color; m_alpha = alpha; }
- const QColor& color() const { return m_color; }
+ const TQColor& color() const { return m_color; }
double alpha() const { return m_alpha; }
private:
- QColor m_color;
+ TQColor m_color;
double m_alpha;
};
@@ -232,32 +232,33 @@ class KisGradientSegment {
class KisGradient : public KisResource {
typedef KisResource super;
Q_OBJECT
+ TQ_OBJECT
public:
- KisGradient(const QString& file);
+ KisGradient(const TQString& file);
virtual ~KisGradient();
virtual bool load();
virtual bool save();
- virtual QImage img();
- virtual QImage generatePreview(int width, int height) const;
+ virtual TQImage img();
+ virtual TQImage generatePreview(int width, int height) const;
- void colorAt(double t, QColor *color, Q_UINT8 *opacity) const;
+ void colorAt(double t, TQColor *color, TQ_UINT8 *opacity) const;
KisGradientSegment *segmentAt(double t) const;
protected:
inline void pushSegment( KisGradientSegment* segment ) { m_segments.push_back(segment); };
- void setImage(const QImage& img);
+ void setImage(const TQImage& img);
- QValueVector<KisGradientSegment *> m_segments;
+ TQValueVector<KisGradientSegment *> m_segments;
private:
bool init();
private:
- QByteArray m_data;
- QImage m_img;
+ TQByteArray m_data;
+ TQImage m_img;
};
#endif // KIS_GRADIENT_H
@@ -48,17 +48,17 @@ enum {
COLOR_INTERP_HSV_CW
};
-// TODO: Replace QColor with KisColor
+// TODO: Replace TQColor with KisColor
class Color {
public: